import java.io.*;
import java.security.*;
import java.security.spec.*;
import java.security.interfaces.*;

public class ServerKeyPair {

    private PublicKey           serverPublicKey;
    private PrivateKey          serverPrivateKey;
    private byte[]              serverEncodedPublicKey;

    public ServerKeyPair() {
        try {
            // Server's public/private keys generator
            // This will be replaced by reading keys from keys repository
            KeyPairGenerator serverKeyGen = KeyPairGenerator.getInstance("DSA");
            serverKeyGen.initialize(1024, new SecureRandom());
            KeyPair kPair = serverKeyGen.generateKeyPair();
            serverPublicKey = kPair.getPublic();
            serverPrivateKey = kPair.getPrivate();
            serverEncodedPublicKey = serverPublicKey.getEncoded();

            // String st = toHexString(serverEncodedPublicKey);
            // System.err.println("Server's Encoded PublicKey: " + st);
        } catch (Exception ex) {
            System.err.println("ServerKeyPair Exception-> " + ex);
        }
    }

    public byte[] getEncodedPublicKey() {
        if (this.serverEncodedPublicKey == null)
            System.err.println("Error");
        return this.serverEncodedPublicKey;
    }

    public PublicKey getPublicKey() {
        return this.serverPublicKey;
    }

    public PrivateKey getPrivateKey() {
        return this.serverPrivateKey;
    }
}
